# civic_scraper.platforms package

## Subpackages

```{toctree}
:maxdepth: 4

civic_scraper.platforms.civic_plus
```

## Module contents

```{eval-rst}
.. automodule:: civic_scraper.platforms
   :members:
   :undoc-members:
   :show-inheritance:
```
